@@ -321,6 +321,7 @@ class Xml(wb.Base):
     def __init__(self, file):
         parser = etree.XMLParser(remove_blank_text=True)
         self._xml = etree.parse(file, parser)
+        self._xml.xinclude()
         self._root = self._xml.getroot()
 
     def _get_state_data(self, state_data, node):
@@ -1725,7 +1726,7 @@ class New_Xml(wb.Base):
         zone_data = self._xml.xpath("//zone_data")
 
         if len(zone_data) == 0:
-            print("Attempting to set non-existent reaction_data.")
+            print("Attempting to set non-existent zone_data.")
             return
 
         for zone in zones:
